# pyappstoreconnect
wrapper for https://appstoreconnect.apple.com/
> :warning: **is not for official api**
this wrapper for NOT offical internal api functions  
based on https://github.com/fastlane/fastlane/tree/master/spaceship

## 2fa
session saved in cache file and valid one month

## example
You can find an example of usage and a basic test [here](test.py)

